@@ -81,7 +81,7 @@ class MultiChannelIterator(IndexArrayIterator):
         if false, image_data_generators are ignored
     elasticdeform_parameters : dict
         parameters passed to elasticdeform function. see: https://github.com/gvtulder/elasticdeform/blob/master/elasticdeform/deform_grid.py
-        main parameters are: "sigma" and "points". alternatively "grid_spacing" can be passed and points will be infered (size//grid_spacing) as well as sigma (min(size/points)).
+        main parameters are: "sigma" and "points". alternatively "grid_spacing" can be passed and points will be infered (size//grid_spacing) as well as sigma (min(sigma_factor*size/points)) with sigma_factor defaults to 1./6 (increase this factor to increase deformation)
         "axis" should not be provided. default "order" is 1 and automatically set to 0 for mask channels.
         mode: out-of-bound strategy
         Applied before channels_postprocessing_function and extract_tile and after image_data_generators
@@ -397,7 +397,7 @@ class MultiChannelIterator(IndexArrayIterator):
             output = _apply_multiplicity(output, self.output_multiplicity) # removes None batches
             return (input, output)
 
-    def _get_batch_by_channel(self, index_array, perform_augmentation, input_only=False, perform_elasticdeform=True, perform_tiling=True):
+    def _get_batch_by_channel(self, index_array, perform_augmentation, input_only=False, perform_elasticdeform=True, perform_tiling=True, **kwargs):
         if self.datasetIO is None: # for concurency issues: file is open lazyly by each worker
             self._open_datasetIO()
         index_array = np.copy(index_array) # so that main index array is not modified
@@ -409,7 +409,7 @@ class MultiChannelIterator(IndexArrayIterator):
             channels.insert(0, channels.pop(channels.index(self.mask_channels[0])))
         aug_param_array = [[dict()]*len(self.channel_keywords) for i in range(len(index_array))]
         for chan_idx in channels:
-            batch_by_channel[chan_idx] = self._get_batches_of_transformed_samples_by_channel(index_ds, index_array, chan_idx, channels[0], aug_param_array, perform_augmentation=perform_augmentation)
+            batch_by_channel[chan_idx] = self._get_batches_of_transformed_samples_by_channel(index_ds, index_array, chan_idx, channels[0], aug_param_array, perform_augmentation=perform_augmentation, **kwargs)
 
         if perform_elasticdeform or perform_tiling: ## elastic deform do not support float16 type -> temporarily convert to float32
             channels = [c for c in batch_by_channel.keys() if c>=0]
@@ -447,7 +447,8 @@ class MultiChannelIterator(IndexArrayIterator):
             image_shape = batch_by_channel[channels[0]].shape[1:-1]
             grid_spacing = ensure_multiplicity(len(image_shape), self.elasticdeform_parameters.pop('grid_spacing', 15))
             points = self.elasticdeform_parameters.pop('points', [max(5, 1+s//gs) for s, gs in zip(image_shape, grid_spacing)])
-            sigma_factor = self.elasticdeform_parameters.pop('sigma_factor', 1./8)
+            grid_spacing = [s/float(n-1) for s, n in zip(image_shape, points)] # actual grid spacing
+            sigma_factor = self.elasticdeform_parameters.pop('sigma_factor', 1./6)
             sigma = self.elasticdeform_parameters.pop('sigma', np.min([sigma_factor*s/(p-1) for s, p in zip(image_shape, points)]))
             batches = [batch_by_channel[chan_idx] for chan_idx in channels]
 
@@ -461,7 +462,9 @@ class MultiChannelIterator(IndexArrayIterator):
             # set zero displacement at edges to avoid out-of-bounds artifacts
             displacement[:, [0,-1], :] = 0
             displacement[:, :, [0,-1]] = 0
-
+            # limit displacement to half of grid spacing to avoid "spirals" (crossing points)
+            displacement[0] = np.minimum(np.abs(displacement[0]), grid_spacing[0]/4) * np.sign(displacement[0])
+            displacement[1] = np.minimum(np.abs(displacement[1]), grid_spacing[1]/4) * np.sign(displacement[1])
             batches = ed.deform_grid(batches, displacement, order=order, mode=mode, axis=axis, **self.elasticdeform_parameters)
 
             for i, chan_idx in enumerate(channels):
@@ -502,7 +505,7 @@ class MultiChannelIterator(IndexArrayIterator):
         else:
             return [self._apply_postprocessing_and_concat_weight_map(batch_by_channel[chan_idx], i) for i, chan_idx in enumerate(self.output_channels)]
 
-    def _get_batches_of_transformed_samples_by_channel(self, index_ds, index_array, chan_idx, ref_chan_idx, aug_param_array=None, perform_augmentation=True, transfer_aug_param_function=lambda source, dest:copy_geom_tranform_parameters(source, dest)):
+    def _get_batches_of_transformed_samples_by_channel(self, index_ds, index_array, chan_idx, ref_chan_idx, aug_param_array=None, perform_augmentation=True, transfer_aug_param_function=lambda source, dest:copy_geom_tranform_parameters(source, dest), **kwargs):
         """Generate a batch of transformed sample for a given channel
 
         Parameters
@@ -526,7 +529,7 @@ class MultiChannelIterator(IndexArrayIterator):
 
         """
 
-        batch = self._read_image_batch(index_ds, index_array, chan_idx, ref_chan_idx, aug_param_array)
+        batch = self._read_image_batch(index_ds, index_array, chan_idx, ref_chan_idx, aug_param_array, **kwargs)
         # apply augmentation
         image_data_generator = self.image_data_generators[chan_idx] if self.perform_data_augmentation and perform_augmentation and self.image_data_generators!=None else None
         for i in range(batch.shape[0]):
@@ -537,17 +540,17 @@ class MultiChannelIterator(IndexArrayIterator):
                         transfer_aug_param_function(aug_param_array[i][ref_chan_idx], params)
                     for k,v in params.items():
                         aug_param_array[i][chan_idx][k]=v
-                batch[i] = self._apply_augmentation(batch[i], chan_idx, params)
+                batch[i] = self._apply_augmentation(batch[i], chan_idx, params, **kwargs)
         return batch
 
-    def _apply_augmentation(self, img, chan_idx, aug_params):
+    def _apply_augmentation(self, img, chan_idx, aug_params, **kwargs):
         image_data_generator = self.image_data_generators[chan_idx]
         if image_data_generator is not None:
             img = image_data_generator.apply_transform(img, aug_params)
             img = image_data_generator.standardize(img)
         return img
 
-    def _read_image_batch(self, index_ds, index_array, chan_idx, ref_chan_idx, aug_param_array):
+    def _read_image_batch(self, index_ds, index_array, chan_idx, ref_chan_idx, aug_param_array, **kwargs):
         # read all images # TODO read all image per ds at once.
         # in case of group scaling : group index is retrieved:
         grp_idx = self._get_grp_idx(index_array + self.ds_off[index_ds]) if self.group_scaling is not None else [0]*len(index_array)
